@@ -235,7 +235,7 @@ LaplacesDemon <- function(Model=NULL, Data=NULL, Adaptive=0,
                     {
                     Dev[length(Dev)] <- Mo1[[2]]
                     Mon <- as.matrix(Mon)
-                    Mon[NROW(Mon),] <- Mo1[[3]]
+                    Mon[nrow(Mon),] <- Mo1[[3]]
                     }
                }
           ### Delayed Rejection: Second Stage Proposals
@@ -281,7 +281,7 @@ LaplacesDemon <- function(Model=NULL, Data=NULL, Adaptive=0,
                          {
                          Dev[length(Dev)] <- Mo1[[2]]
                          Mon <- as.matrix(Mon)
-                         Mon[NROW(Mon),] <- Mo1[[3]]
+                         Mon[nrow(Mon),] <- Mo1[[3]]
                          }
                     }
                }
@@ -322,13 +322,14 @@ LaplacesDemon <- function(Model=NULL, Data=NULL, Adaptive=0,
      Mon <- ifelse(is.nan(Mon), 0, Mon)
      ### Assess Stationarity
      cat("\nAssessing Stationarity\n")
-     burn.start <- trunc(seq(from=1, to=NROW(thinned), by=NROW(thinned)/10))
+     burn.start <- trunc(seq(from=1, to=nrow(thinned),
+          by=nrow(thinned)/10))
      geweke <- matrix(9, length(burn.start), LIV)
      geweke.ct <- rep(0, LIV)
      options(warn=-1)
      for (i in 1:length(burn.start))
           {
-          thinned2 <- thinned[burn.start[i]:NROW(thinned),]
+          thinned2 <- thinned[burn.start[i]:nrow(thinned),]
           test <- try(as.vector(Geweke.Diagnostic(thinned2)), silent=TRUE)
           if(is.numeric(test)) geweke[i,] <- as.vector(test)
           }
@@ -338,12 +339,12 @@ LaplacesDemon <- function(Model=NULL, Data=NULL, Adaptive=0,
      geweke <- ifelse(is.nan(geweke), 9, geweke)
      geweke <- ifelse({geweke > -2} & {geweke < 2}, TRUE, FALSE)
      for (j in 1:LIV) {geweke.ct[j] <- which(geweke[,j] == TRUE)[1]}
-     geweke.ct <- ifelse(is.na(geweke.ct), NROW(thinned), geweke.ct)
+     geweke.ct <- ifelse(is.na(geweke.ct), nrow(thinned), geweke.ct)
      BurnIn <- burn.start[max(geweke.ct)]
-     BurnIn <- ifelse(is.na(BurnIn), NROW(thinned), BurnIn)
+     BurnIn <- ifelse(is.na(BurnIn), nrow(thinned), BurnIn)
      ### Assess Thinning and ESS Size for all parameter samples
      cat("Assessing Thinning and ESS\n")
-     acf.temp <- matrix(1, trunc(10*log10(NROW(thinned))), LIV)
+     acf.temp <- matrix(1, trunc(10*log10(nrow(thinned))), LIV)
      ESS1 <- Rec.Thin <- rep(1, LIV)
      for (j in 1:LIV)
           {
@@ -357,16 +358,16 @@ LaplacesDemon <- function(Model=NULL, Data=NULL, Adaptive=0,
      ESS2 <- ESS(Dev)
      ESS3 <- ESS(Mon)
      ### Assess ESS for stationary samples
-     if(BurnIn < NROW(thinned))
+     if(BurnIn < nrow(thinned))
           {
-          ESS4 <- ESS(thinned[BurnIn:NROW(thinned),])
-          ESS5 <- ESS(Dev[BurnIn:NROW(Dev),])
-          ESS6 <- ESS(Mon[BurnIn:NROW(Mon),])
+          ESS4 <- ESS(thinned[BurnIn:nrow(thinned),])
+          ESS5 <- ESS(Dev[BurnIn:nrow(Dev),])
+          ESS6 <- ESS(Mon[BurnIn:nrow(Mon),])
           }
      ### Posterior Summary Table 1: All Thinned Samples
      cat("Creating Summaries\n")
      Mon <- as.matrix(Mon)
-     Num.Mon <- NCOL(Mon)
+     Num.Mon <- ncol(Mon)
      Summ1 <- matrix(NA, LIV, 7, dimnames=list(Data$parm.names,
           c("Mean","SD","MCSE","ESS","LB","Median","UB")))
      Summ1[,1] <- colMeans(thinned)
@@ -403,17 +404,17 @@ LaplacesDemon <- function(Model=NULL, Data=NULL, Adaptive=0,
      ### Posterior Summary Table 2: Stationary Samples
      Summ2 <- matrix(NA, LIV, 7, dimnames=list(Data$parm.names,
           c("Mean","SD","MCSE","ESS","LB","Median","UB")))
-     if(BurnIn < NROW(thinned))
+     if(BurnIn < nrow(thinned))
           {
-          Summ2[,1] <- colMeans(thinned[BurnIn:NROW(thinned),])
-          Summ2[,2] <- apply(thinned[BurnIn:NROW(thinned),], 2, sd)
+          Summ2[,1] <- colMeans(thinned[BurnIn:nrow(thinned),])
+          Summ2[,2] <- apply(thinned[BurnIn:nrow(thinned),], 2, sd)
           Summ2[,3] <- Summ2[,2] / sqrt(ESS4)
           Summ2[,4] <- ESS4
-          Summ2[,5] <- apply(thinned[BurnIn:NROW(thinned),], 2, quantile,
+          Summ2[,5] <- apply(thinned[BurnIn:nrow(thinned),], 2, quantile,
                c(0.025))
-          Summ2[,6] <- apply(thinned[BurnIn:NROW(thinned),], 2, quantile,
+          Summ2[,6] <- apply(thinned[BurnIn:nrow(thinned),], 2, quantile,
                c(0.500))
-          Summ2[,7] <- apply(thinned[BurnIn:NROW(thinned),], 2, quantile,
+          Summ2[,7] <- apply(thinned[BurnIn:nrow(thinned),], 2, quantile,
                c(0.975))
           Deviance <- rep(NA,7)
           Deviance[1] <- mean(Dev[BurnIn:length(Dev)])
@@ -429,29 +430,29 @@ LaplacesDemon <- function(Model=NULL, Data=NULL, Adaptive=0,
           Summ2 <- rbind(Summ2, Deviance)
           for (j in 1:Num.Mon) {
                Monitor <- rep(NA,7)
-               Monitor[1] <- mean(Mon[BurnIn:NROW(thinned),j])
-               Monitor[2] <- sd(Mon[BurnIn:NROW(thinned),j])
-               Monitor[3] <- sd(Mon[BurnIn:NROW(thinned),j]) /
+               Monitor[1] <- mean(Mon[BurnIn:nrow(thinned),j])
+               Monitor[2] <- sd(Mon[BurnIn:nrow(thinned),j])
+               Monitor[3] <- sd(Mon[BurnIn:nrow(thinned),j]) /
                     sqrt(ESS6[j])
                Monitor[4] <- ESS6[j]
-               Monitor[5] <- as.numeric(quantile(Mon[BurnIn:NROW(Mon),j],
+               Monitor[5] <- as.numeric(quantile(Mon[BurnIn:nrow(Mon),j],
                     probs=0.025, na.rm=TRUE))
-               Monitor[6] <- as.numeric(quantile(Mon[BurnIn:NROW(Mon),j],
+               Monitor[6] <- as.numeric(quantile(Mon[BurnIn:nrow(Mon),j],
                     probs=0.500, na.rm=TRUE))
-               Monitor[7] <- as.numeric(quantile(Mon[BurnIn:NROW(Mon),j],
+               Monitor[7] <- as.numeric(quantile(Mon[BurnIn:nrow(Mon),j],
                     probs=0.975, na.rm=TRUE))
                Summ2 <- rbind(Summ2, Monitor)
                rownames(Summ2)[nrow(Summ2)] <- Data$mon.names[j]
                }
           }
      ### Column names to samples
-     if(NCOL(Mon) == length(Data$mon.names)) colnames(Mon) <- Data$mon.names
-     if(NCOL(thinned) == length(Data$parm.names)) {
+     if(ncol(Mon) == length(Data$mon.names)) colnames(Mon) <- Data$mon.names
+     if(ncol(thinned) == length(Data$parm.names)) {
           colnames(thinned) <- Data$parm.names}
      ### Logarithm of the Marginal Likelihood
      if(Algorithm == "Random-Walk Metropolis") {
           cat("Estimating Log of the Marginal Likelihood\n")
-          if(BurnIn >= NROW(thinned)) {LML <- LML(Model, Data,
+          if(BurnIn >= nrow(thinned)) {LML <- LML(Model, Data,
                thinned[nrow(thinned),])}
           else {LML <- LML(Model, Data, Summ2[1:LIV,6])}}
      else {LML <- list(LML=NA, VarCov=NA)}
@@ -468,7 +469,7 @@ LaplacesDemon <- function(Model=NULL, Data=NULL, Adaptive=0,
           DIC1=c(mean(as.vector(Dev)),
                var(as.vector(Dev))/2,
                mean(as.vector(Dev)) + var(as.vector(Dev))/2),
-          DIC2=if(BurnIn < NROW(thinned)) {
+          DIC2=if(BurnIn < nrow(thinned)) {
                c(mean(as.vector(Dev[BurnIn:length(Dev)])),
                var(as.vector(Dev[BurnIn:length(Dev)]))/2,
                mean(as.vector(Dev[BurnIn:length(Dev)])) + 
@@ -484,14 +485,14 @@ LaplacesDemon <- function(Model=NULL, Data=NULL, Adaptive=0,
           Parameters=LIV,
           Periodicity=Periodicity,
           Posterior1=thinned,
-          Posterior2=thinned[BurnIn:NROW(thinned),],
+          Posterior2=thinned[BurnIn:nrow(thinned),],
           Rec.BurnIn.Thinned=BurnIn,
           Rec.BurnIn.UnThinned=BurnIn*Thinning,
           Rec.Thinning=min(1000, max(Rec.Thin)),
           Status=Status,
           Summary1=Summ1,
           Summary2=Summ2,
-          Thinned.Samples=NROW(thinned), Thinning=Thinning)
+          Thinned.Samples=nrow(thinned), Thinning=Thinning)
      class(LaplacesDemon.out) <- "demonoid"
      cat("\nLaplace's Demon has finished.\n")
      return(LaplacesDemon.out)
